#-*- coding: utf-8 -*-

import os
import sys
from math import *
from numpy import *
from scipy.io import *
from pylab import *
from curses.ascii import TAB
sys.path.insert(0, "../../P-files/")
from wtraceoinfil import *
from munk import *


os.system("rm -rf eig.mat")

case_title = "Munk profile & eigenrays"

'''%==================================================================
% 
% Define source data:
%
%==================================================================
'''
freq   =    50
Rmaxkm =   101
Rmax = Rmaxkm*1000
Dmax   =  5000 

ray_step = Rmax/1000 

zs = 1000
rs = 0
nthetas = 101
thetamax = 14

thetas = linspace(-thetamax,thetamax,nthetas)

source_data = {}
source_data['ds'] = ray_step
source_data['position'] = [rs,zs]
source_data['rbox'] = [rs-1,Rmax]
source_data['f'] = freq
source_data['thetas'] = thetas

'''%==================================================================
%
% Define altimetry data:
% 
%=================================================================='''

alti = [rs-2, Rmax+2]
altimetry  = array([alti,[0,0]])

surface_data = {}
surface_data['type']  =   "V"#; % 
surface_data['ptype'] =   "H"#; % Homogeneous
surface_data['units'] =   "W"#; % (Attenuation Units) Wavelenght
surface_data['itype'] =  "FL"#;
surface_data['x']     = altimetry #; % Surface coordinates
surface_data['properties'] = [0.0,0.0,0.0,0.0,0.0] #aqui são 5 parametros

#==================================================================
#
# Define sound speed data:
#
#==================================================================
#disp('Defining the sound speed field...')

c1 = 1500
z1 = 1300

depths = linspace(0,Dmax,1001)

c = munk( depths, z1, c1 )

ssp_data = {}
ssp_data['cdist'] = "c(z,z)" #; # Sound speed field
ssp_data['cclass'] = "TABL"
ssp_data['z']    = depths
ssp_data['r']    = []
ssp_data['c']    = c 

'''%==================================================================
%  
%  Define object data:
%  
%=================================================================='''

object_data = {}
object_data['nobjects'] = 0 #; % No objects

'''%==================================================================
% 
% Define bathymetry data:
%
%=================================================================='''

#% Gaussian sea mountain: 

bati = [rs-2, Rmax+2]
bathymetry = array([bati, [Dmax, Dmax]])

bottom_data = {}
bottom_data['type']   = "E"
bottom_data['ptype']  = "H" #; % Homogeneous bottom
bottom_data['units']  =  "W" #; % (Attenuation Units) Wavelenght
bottom_data['itype']  = "FL" #; % Bottom interpolation type 
bottom_data['x']      = bathymetry #;     % Bottom coordinates 
bottom_data['properties'] = [1550.0,600.0,2.0,0.1,0.0] #; % Bottom properties (speed, speed, density, absorption coefficient)

'''%==================================================================
%
% Define output data:
%
%=================================================================='''

ranges = array([100*1000])
depths = array([zs]) 

m = ranges.size
n = depths.size

output_data={}
output_data['ctype']       = "ERF" #''';
output_data['array_shape'] = "RRY" #''';
output_data['r']           = ranges
output_data['z']           = depths
output_data['miss']        = 100


'''%==================================================================
%  
%  Call the function:
%  
%=================================================================='''

print('Writing TRACEO waveguide input file...')

wtraceoinfil('munk.in',case_title,source_data,surface_data,ssp_data,object_data,bottom_data,output_data)

print('Calling TRACEO...')

os.system('runtraceo munk')

print('Reading the output data...')

data = loadmat('eig.mat')

#thetas = data["neigrays"] 
nthetas = int( squeeze( data["neigrays"] ) )
# com o squeeze e sem o squeeze ele funciona, então pq colocar
#nthetas = thetas.size
figure(1)
hold(True)

for i in range(1, nthetas+1):
    if i<10:
        rayname = "ray0000" + str(i)
    elif i<100:
        rayname = "ray000" + str(i)
    elif i<1000:
        rayname = "ray00" + str(i)
    elif i<10000:
        rayname = "ray0" + str(i)
    else:
        rayname = "ray" + str(i)
            
    rayi = data[rayname]
    r = rayi[0,]
    z =-rayi[1,]
    plot(r,z)
    
xlabel('Range(m)')
ylabel('Depht (m)')
plot(bathymetry[0,],-bathymetry[1,],color='r' , linewidth=2, )
plot(altimetry[0,],-altimetry[1,],color='b',linewidth=2)
grid(True)

title('Traceo Munk waveguide, eigenrays')

xlim(0, Rmax)
ylim(-Dmax, 0)
#exit()
show()
    
print "feito"
