#-*- coding: utf-8 -*-

import os
import sys
from math import *
from numpy import *
from scipy.io import *
from pylab import *
from curses.ascii import TAB
sys.path.insert(0, "../../P-files/")
from wtraceoinfil import *
from munk import *

os.system("rm -rf rco.mat")

case_title = "Munk profile & variable boundaries"

'''%==================================================================
% 
% Define source data:
%
%==================================================================
'''
freq   =    50
Rmaxkm =   101
Rmax = Rmaxkm*1000
Dmax   =  5000 

ray_step = Rmax/1000 

zs = 1000
rs = 0
np2 = 81
thetamax = 14
la = linspace(-thetamax,thetamax,np2)

source_data = {}
source_data['ds'] = ray_step
source_data['position'] = [rs,zs]
source_data['rbox'] = [rs-1,Rmax+1]
source_data['f'] = freq
source_data['thetas'] = la

'''%==================================================================
%
% Define altimetry data:
% 
%=================================================================='''

nati = 501

rati = linspace(rs-2,Rmax+2,nati)
zati = sin( (10*pi*rati/Rmax) )
zati = 200.0*zati*zati

#altimetry(1,:) = linspace(rs-2,Rmax,np3);
#altimetry(2,:) = 200*sin( (10*pi*altimetry(1,:)/Rmax) ).^2;


altimetry  = array([rati,zati])

surface_data = {}
surface_data['type']  =   "V"#; % 
surface_data['ptype'] =   "H"#; % Homogeneous
surface_data['units'] =   "W"#; % (Attenuation Units) Wavelenght
surface_data['itype'] =  "2P"#;
surface_data['x']     = altimetry #; % Surface coordinates

surface_data['properties'] = [1510.0,600.0,0.99,0.1,0.0] #aqui são 5 parametros

#==================================================================
#
# Define sound speed data:
#
#==================================================================
#disp('Defining the sound speed field...')

np1 = 51

ranges = linspace(0,Rmax,np1)
depths = linspace(0,Dmax,np1)

rangeskm = ranges/1000

z1 = linspace(1000,2000,np1)
c1 = 1500
#arq = ""
c = array([munk(depths, z1[0], c1)])
CC = c.T
i = 0
j = 0
for i in range(1, np1):
    #[c,cz,czz] = munk(depths , z1(i) , c1 )
    c = array([munk(depths, z1[i], c1)])
    CC = hstack((CC,c.T))

ssp_data = {}
ssp_data['cdist'] = "c(r,z)" #'''; # Sound speed field
ssp_data['cclass'] = "TABL"
ssp_data['z']    = depths
ssp_data['r']    = ranges
ssp_data['c']    = CC

'''%==================================================================
%  
%  Define object data:
%  
%=================================================================='''

object_data = {}
object_data['nobjects'] = 0 #; % No objects

'''%==================================================================
% 
% Define bathymetry data:
%
%=================================================================='''

#% Gaussian sea mountain: 


#bathymetry = array([[rs-2,Rmax+2], [Dmax, Dmax]])
bati = linspace(rs-2,Rmax+2,nati) 
aaux = (bati - 0.5*Rmax )
zati = -1500*exp(-aaux*aaux/1e9) + Dmax

bathymetry = array([bati, zati])

bottom_data = {}
bottom_data['type']   = "E"
bottom_data['ptype']  = "H" #; % Homogeneous bottom
bottom_data['units']  =  "W" #; % (Attenuation Units) Wavelenght
bottom_data['itype']  = "2P" #; % Bottom interpolation type 
bottom_data['x']      = bathymetry #;     % Bottom coordinates 
bottom_data['properties'] = [1550.0,600.0,2.0,0.1,0.0] #; % Bottom properties (speed, speed, density, absorption coefficient)

'''%==================================================================
%
% Define output data:
%
%=================================================================='''

ranges = array([Rmax])
depths = array([Dmax]) 

m = ranges.size
n = depths.size

output_data={}
output_data['ctype']       = "RCO" #''';
output_data['array_shape'] = "RRY" #''';
output_data['r']           = ranges
output_data['z']           = depths
output_data['miss']        = 0.5

'''%==================================================================
%  
%  Call the function:
%  
%=================================================================='''

print('Writing TRACEO waveguide input file...')

wtraceoinfil('munk.in',case_title,source_data,surface_data,ssp_data,object_data,bottom_data,output_data)

print('Calling TRACEO...')

os.system('runtraceo munk')

print('Reading the output data...')

data = loadmat('rco.mat')

thetas = data["ray_elev"] 

nthetas = thetas.size
figure(1)
hold(True)
for i in range(1, nthetas+1):
    if i<10:
        rayname = "ray0000" + str(i)
    elif i<100:
        rayname = "ray000" + str(i)
    elif i<1000:
        rayname = "ray00" + str(i)
    elif i<10000:
        rayname = "ray0" + str(i)
    else:
        rayname = "ray" + str(i)
        
    rayi = data[rayname]
    r = rayi[0,]
    z =-rayi[1,]
    plot(r,z)
    
xlabel('Range(m)')
ylabel('Depht (m)')
plot(bathymetry[0,],-bathymetry[1,],color='r' , linewidth=2, )
plot(altimetry[0,],-altimetry[1,],color='b',linewidth=2)
grid(True)

title('Traceo Munk waveguide, ray coordinates')

xlim(0, Rmax)
ylim(-Dmax, 0)
#exit()
show()
    
print "feito"
