#-*- coding: utf-8 -*-

import os
import sys
from math import *
from numpy import *
from scipy.io import *
from pylab import *
sys.path.insert(0, "../../P-files")
from wtraceoinfil import *
from curses.ascii import TAB
from scipy.signal.ltisys import lsim

os.system("rm -rf aad.mat")

case_title = "Pekeris waveguide & arrival calculations"

freq       =  100
Rmaxboxkm  = 5.1
Rmaxbox = Rmaxboxkm*1000
Rmaxhrykm  = 5.0
Rmaxhry = Rmaxhrykm*1000
Dmax   =  1000
zs = 500
rs = 0
thetamax = 85
nthetas = 2001
m = 1001
n =  501
ranges = linspace(-Rmaxhry,Rmaxhry,m)
zr     = linspace(0,Dmax,n)

'''%==================================================================
% 
% Define source data:
%
%==================================================================
'''
ray_step = Rmaxbox/1000


la = linspace(-thetamax,thetamax,nthetas)

source_data = {}
source_data['ds'] = ray_step
source_data['position'] = [rs,zs]
source_data['rbox'] = [-Rmaxbox,Rmaxbox]
source_data['f'] = freq
source_data['thetas'] = la

'''%==================================================================
%
% Define altimetry data:
% 
%=================================================================='''

alti = [-Rmaxbox-1,Rmaxbox+1]
altimetry  = array([alti,[0,0]])

surface_data = {}
surface_data['type']  =   "V"#; % 
surface_data['ptype'] =   "H"#; % Homogeneous
surface_data['units'] =   "W"#; % (Attenuation Units) Wavelenght
surface_data['itype'] =  "FL"#;
surface_data['x']     = altimetry #; % Surface coordinates
surface_data['properties'] = [0.0,0.0,0.0,0.0,0.0] #aqui são 5 parametros

#==================================================================
#
# Define sound speed data:
#
#==================================================================

c0 = 1500

ssp_data = {}
ssp_data['cdist'] = "c(z,z)" #; # Sound speed field
ssp_data['cclass'] = "ISOV"
ssp_data['z']    = array([0, Dmax])
ssp_data['r']    = []
ssp_data['c']    = array([c0, c0]) 

'''%==================================================================
%  
%  Define object data:
%  
%=================================================================='''

object_data = {}
object_data['nobjects'] = 0 #; % No objects

'''%==================================================================
% 
% Define bathymetry data:
%
%=================================================================='''

bati = [-Rmaxbox-1, 2000, 2010, 2990, 3000, Rmaxbox+1]
batu = [Dmax, Dmax, 500, 500, Dmax, Dmax]

bathymetry = array([bati, batu])

bottom_data = {}
bottom_data['type']   = "E"
bottom_data['ptype']  = "H" #; % Homogeneous bottom
bottom_data['units']  =  "W" #; % (Attenuation Units) Wavelenght
bottom_data['itype']  = "2P" #; % Bottom interpolation type 
bottom_data['x']      = bathymetry #;     % Bottom coordinates 
bottom_data['properties'] = [2000.0, 0.0, 2.0, 0.5, 0.0] #; % Bottom properties (speed, speed, density, absorption coefficient)

'''%==================================================================
%
% Define output data:
%
%=================================================================='''

output_data={}
output_data['ctype']       = "ADP" #''';
output_data['array_shape'] = "VRY" #''';
output_data['r']           = array([Rmaxhry])
output_data['z']           = array([Dmax*0.75])
output_data['miss']        = 0.5

'''%==================================================================
%  
%  Call the function:
%  
%=================================================================='''

print('Writing TRACEO waveguide input file...')

wtraceoinfil('pekeris.in',case_title,source_data,surface_data,ssp_data,object_data,bottom_data,output_data)

print('Calling TRACEO...')

os.system('runtraceo pekeris')

print('Reading the output data...')

data = loadmat('aad.mat')

thetas = data["neigrays"]

rayname = 'aad00000'

nthetas =  int(squeeze(thetas[0,]))
tau = zeros( nthetas )
ampl = zeros( nthetas ) + 1j*zeros( nthetas )

if  thetas >  0:
    for i in range(1, nthetas + 1):
        if i<10:
            rayname = "aad0000" + str(i)
        elif i<100:
            rayname = "aad000" + str(i)
        elif i<1000:
            rayname = "aad00" + str(i)
        elif i<10000:
            rayname = "aad0" + str(i)
        else:
            rayname = "aad" + str(i)
        rayi = squeeze(data[rayname])
        tau[i-1] = rayi[2]
        amp = rayi[3] + 1j*rayi[4]
        ampl[i-1] = amp*exp( 1j*rayi[5] )
    else:
        print ('no arrivals found...')
        print "feito"



markerline, stemlines, baseline = plt.stem(tau, abs(ampl), '-.')
plt.setp(markerline, 'markerfacecolor', 'b')
plt.setp(baseline, 'color', 'r', 'linewidth', 2)

xlabel('Travel time (s)')
ylabel('Amplitude')
title('TRACEO - Pekeris waveguide, delay calculations')
grid(True) 

show()
    
print "feito"
