#-*- coding: utf-8 -*-

import os
import sys
from math import *
from numpy import *
from scipy.io import *
from pylab import *
from curses.ascii import TAB
sys.path.insert(0, "../../P-files")
from wtraceoinfil import *

os.system("rm -rf ari.mat")

case_title = "Pekeris waveguide & all ray information"

'''%==================================================================
% 
% Define source data:
%
%==================================================================
'''
freq   =    717
Rmaxkm =   1
Rmax = Rmaxkm*1000
Dmax   =  100

ray_step = Rmax/1000 

zs = 25
rs = 0
nthetas = 21
thetamax = 10

thetas = linspace(-thetamax,thetamax,nthetas)

source_data = {}
source_data['ds'] = 0
source_data['position'] = [rs,zs]
source_data['rbox'] = [rs-1,Rmax+1]
source_data['f'] = freq
source_data['thetas'] = thetas

'''%==================================================================
%
% Define altimetry data:
% 
%=================================================================='''

alti = [rs-2, Rmax+2]
altimetry  = array([alti,[0,0]])

surface_data = {}
surface_data['type']  =   "V"#; % 
surface_data['ptype'] =   "H"#; % Homogeneous
surface_data['units'] =   "W"#; % (Attenuation Units) Wavelenght
surface_data['itype'] =  "FL"#;
surface_data['x']     = altimetry #; % Surface coordinates
surface_data['properties'] = [0.0,0.0,0.0,0.0,0.0] #aqui são 5 parametros

#==================================================================
#
# Define sound speed data:
#
#==================================================================

c0 = 1500

ssp_data = {}
ssp_data['cdist'] = "c(z,z)" #; # Sound speed field
ssp_data['cclass'] = "ISOV"
ssp_data['z']    = array([0, Dmax])
ssp_data['r']    = []
ssp_data['c']    = array([c0, c0]) 

'''%==================================================================
%  
%  Define object data:
%  
%=================================================================='''

object_data = {}
object_data['nobjects'] = 0 #; % No objects

'''%==================================================================
% 
% Define bathymetry data:
%
%=================================================================='''

#% Gaussian sea mountain: 

bati = [rs-2, Rmax+2]
bathymetry = array([bati, [Dmax, Dmax]])

bottom_data = {}
bottom_data['type']   = "E"
bottom_data['ptype']  = "H" #; % Homogeneous bottom
bottom_data['units']  =  "W" #; % (Attenuation Units) Wavelenght
bottom_data['itype']  = "FL" #; % Bottom interpolation type 
bottom_data['x']      = bathymetry #;     % Bottom coordinates 
bottom_data['properties'] = [1700.0,0.0,1.7,0.7,0.0] #; % Bottom properties (speed, speed, density, absorption coefficient)

'''%==================================================================
%
% Define output data:
%
%=================================================================='''

output_data={}
output_data['ctype']       = "ARI" #''';
output_data['array_shape'] = "VRY" #''';
output_data['r']           = array([Rmax])
output_data['z']           = array([Dmax])
output_data['miss']        = 1

'''%==================================================================
%  
%  Call the function:
%  
%=================================================================='''

print('Writing TRACEO waveguide input file...')

wtraceoinfil('pekeris.in',case_title,source_data,surface_data,ssp_data,object_data,bottom_data,output_data)

print('Calling TRACEO...')


os.system('runtraceo pekeris')

print('Reading the output data...')

data = loadmat('ari.mat')

thetas = data["ray_elev"] 

nthetas = thetas.size
figure(1)
hold(True)
for i in range(1, nthetas+1):
    if i<10:
        rayname = "ray0000" + str(i)
    elif i<100:
        rayname = "ray000" + str(i)
    elif i<1000:
        rayname = "ray00" + str(i)
    elif i<10000:
        rayname = "ray0" + str(i)
    else:
        rayname = "ray" + str(i)
        
    rayi = data[rayname]
    r = rayi[0,]
    z =-rayi[1,]
    plot(r,z)
    
xlabel('Range(m)')
ylabel('Depht (m)')
plot(bathymetry[0,],-bathymetry[1,],color='r' , linewidth=2, )
plot(altimetry[0,],-altimetry[1,],color='b',linewidth=2)
grid(True)

title('TRACEO - Pekeris waveguide, all ray information')

xlim(0, Rmax)
ylim(-Dmax, 0)
show()
    
print "feito"

