#-*- coding: utf-8 -*-

import os
import sys
from math import *
from numpy import *
from scipy.io import *
from pylab import *
import matplotlib.pyplot as plt
from curses.ascii import TAB
sys.path.insert(0, "../../P-files")
from wtraceoinfil import *

os.system("rm -rf cpr.mat")

case_title = "Pekeris waveguide & coherent pressure"

'''%==================================================================
% 
% Define source data:
%
%==================================================================
'''
freq   = 717
Rmaxkm = 0.2
Rmax = Rmaxkm*1000
Dmax   =  50
 
ray_step = Rmax/1000 
zs = Dmax/2
rs = 0
thetamax = 15
nthetas = 50
la = linspace(-thetamax,thetamax,nthetas)

source_data = {}
source_data['ds'] = ray_step
source_data['position'] = [rs,zs]
source_data['rbox'] = [rs-1,Rmax+1]
source_data['f'] = freq
source_data['thetas'] = la

'''%==================================================================
%
% Define altimetry data:
% 
%=================================================================='''

alti = [rs-2, Rmax+2]
altimetry  = array([alti,[0,0]])

surface_data = {}
surface_data['type']  =   "V"#; % 
surface_data['ptype'] =   "H"#; % Homogeneous
surface_data['units'] =   "W"#; % (Attenuation Units) Wavelenght
surface_data['itype'] =  "FL"#;
surface_data['x']     = altimetry #; % Surface coordinates
surface_data['properties'] = [0.0,0.0,0.0,0.0,0.0] #aqui são 5 parametros

#==================================================================
#
# Define sound speed data:
#
#==================================================================

c0 = 1500

ssp_data = {}
ssp_data['cdist'] = "c(z,z)" #; # Sound speed field
ssp_data['cclass'] = "ISOV"
ssp_data['z']    = array([0, Dmax])
ssp_data['r']    = []
ssp_data['c']    = array([c0, c0]) 

'''%==================================================================
%  
%  Define object data:
%  
%=================================================================='''
npo = 50 #
cobjp = 2000 #velocida compressional do objeto
cobjs = 200 #velocidade cisalhamento
rhoo = 5#densidade do objeto
alphao = 0 #atnuação compressional do objeto
R0 = 5 #raio da esfera
factor = 1
ro = Rmax/2 #ponto central da esfera em distancia
zo = Dmax/2 #ponto central da esfera em profundidade

#definição de um objeto em forma de esfera
robj  =  factor*R0*cos( linspace(pi,0,npo) ) + ro #coordenadas horizontais do objeto
zup   =         R0*sin( linspace(pi,0,npo) ) + Dmax/2 #face superior do objeto
zdn   =        -R0*sin( linspace(pi,0,npo) ) + Dmax/2 #face inferior do objeto

xboj = array([robj,zdn,zup])

object_data = {}
object_data['nobjects'] = 1 #; % No objects
object_data['itype']     = "2P" #; % Objects interpolation type
object_data['npobjects'] = [npo] #; % Number of points in each object
object_data['type']      = ["R"] #; %
object_data['units']     = ["W"]#; % (Attenuation Units) Wavelenght 
object_data['properties'] = [cobjp, cobjs, rhoo, alphao, alphao],[]
object_data['x'] = (xboj, [])

'''%==================================================================
% 
% Define bathymetry data:
%
%=================================================================='''

#% Gaussian sea mountain: 

bati = [rs-2, Rmax+2]
bathymetry = array([bati, [Dmax, Dmax]])

bottom_data = {}
bottom_data['type']   = "E"
bottom_data['ptype']  = "H" #; % Homogeneous bottom
bottom_data['units']  =  "W" #; % (Attenuation Units) Wavelenght
bottom_data['itype']  = "FL" #; % Bottom interpolation type 
bottom_data['x']      = bathymetry #;     % Bottom coordinates 
bottom_data['properties'] = [1700.0,0.0,1.7,0.7,0.0] #; % Bottom properties (speed, speed, density, absorption coefficient)


'''%==================================================================
%
% Define output data:
%
%=================================================================='''

nra = 201 
rarray = linspace(0,Rmax,nra)
nza = 201 
zarray = linspace(0,Dmax,nza)

output_data={}
output_data['ctype']       = "CPR" #''';
output_data['array_shape'] = "RRY" #''';
output_data['r']           = rarray
output_data['z']           = zarray
output_data['miss']        = 0.5

'''%==================================================================
%  
%  Call the function:
%  
%=================================================================='''

print('Writing TRACEO waveguide input file...')

wtraceoinfil('pekeris.in',case_title,source_data,surface_data,ssp_data,object_data,bottom_data,output_data)

print('Calling TRACEO...')

os.system('runtraceo pekeris')

print('Reading the output data...')

data = loadmat('cpr.mat')

pressure = data['pressure']

x,y=pressure.shape
for xi in range(0,x):
    for yi in range(0,y):
        if abs(pressure[xi,yi])==0:
            pressure[xi,yi]=0.0000001+0.000001j


tl = 20*log10(abs(pressure))

figure(1) 
hold(True)

#--------pressão acústica---------
plt.imshow(np.flipud(tl), extent=[0,Rmax,0,Dmax], aspect='auto')
plt.clim(-90, 0)
plt.set_cmap(cmap=jet())#altera a cor da plotagem
plt.colorbar()

#---------objeto-------------------------
plt.fill_between(robj, zup, zdn ,color='0')

grid(True)

xlim(0, Rmax)
ylim(0, Dmax)

xlabel('Range(m)')
ylabel('Depht (m)')
title('TRACEO - Pekeris waveguide, acoustic pressure')

plt.show()

