#-*- coding: utf-8 -*-

import os
import sys
from math import *
from numpy import *
from scipy.io import *
from pylab import *
import matplotlib.pyplot as plt
from curses.ascii import TAB
sys.path.insert(0, "../../P-files")
from wtraceoinfil import *

os.system("rm -rf pav.mat")

case_title = "Pekeris waveguide & particle velocity"

freq       =  100
Rmaxboxkm  = 5.1
Rmaxbox = Rmaxboxkm*1000
Rmaxhrykm  = 5.0 
Rmaxhry = Rmaxhrykm*1000
Dmax   =  1000
zs = 500 
rs = 0 
thetamax = 20 
nthetas = 301

'''%==================================================================
% 
% Define source data:
%
%==================================================================
'''

ray_step = Rmaxbox/1000 

la = linspace(-thetamax,thetamax,nthetas)

source_data = {}
source_data['ds'] = ray_step
source_data['position'] = [rs,zs]
source_data['rbox'] = [-Rmaxbox, Rmaxbox]
source_data['f'] = freq
source_data['thetas'] = la

'''%==================================================================
%
% Define altimetry data:
% 
%=================================================================='''

alti = [-Rmaxbox-1, Rmaxbox+1]
altimetry  = array([alti,[0,0]])

surface_data = {}
surface_data['type']  =   "V"#; % 
surface_data['ptype'] =   "H"#; % Homogeneous
surface_data['units'] =   "W"#; % (Attenuation Units) Wavelenght
surface_data['itype'] =  "FL"#;
surface_data['x']     = altimetry #; % Surface coordinates
surface_data['properties'] = [0.0,0.0,0.0,0.0,0.0] #aqui são 5 parametros

#==================================================================
#
# Define sound speed data:
#
#==================================================================

c0 = 1500

ssp_data = {}
ssp_data['cdist'] = "c(z,z)" #; # Sound speed field
ssp_data['cclass'] = "ISOV"
ssp_data['z']    = array([0, Dmax])
ssp_data['r']    = []
ssp_data['c']    = array([c0, c0]) 

'''%==================================================================
%  
%  Define object data:
%  
%=================================================================='''

object_data = {}
object_data['nobjects'] = 0 #; % No objects

'''%==================================================================
% 
% Define bathymetry data:
%
%=================================================================='''

#% Gaussian sea mountain: 

bati = [-Rmaxbox-1,2000,2010,2990,3000,Rmaxbox+1]
batu = [Dmax, Dmax, 500, 500,Dmax,Dmax]

bathymetry = array([bati, batu])

bottom_data = {}
bottom_data['type']   = "E"
bottom_data['ptype']  = "H" #; % Homogeneous bottom
bottom_data['units']  =  "W" #; % (Attenuation Units) Wavelenght
bottom_data['itype']  = "2P" #; % Bottom interpolation type 
bottom_data['x']      = bathymetry #;     % Bottom coordinates 
bottom_data['properties'] = [2000.0, 0.0, 2.0, 0.5, 0.0] #; % Bottom properties (speed, speed, density, absorption coefficient)

'''%==================================================================
%
% Define output data:
%
%=================================================================='''

nra = 201
rarray = linspace(0,Rmaxhry,nra)
nza = 201
zarray = linspace(0,Dmax,nza)

output_data={}
output_data['ctype']       = "PAV" #''';
output_data['array_shape'] = "RRY" #''';
output_data['r']           = rarray
output_data['z']           = zarray
output_data['miss']        = 0.5

'''%==================================================================
%  
%  Call the function:
%  
%=================================================================='''

print('Writing TRACEO waveguide input file...')

wtraceoinfil('pekeris.in',case_title,source_data,surface_data,ssp_data,object_data,bottom_data,output_data)

print('Calling TRACEO...')

os.system('runtraceo pekeris')

print('Reading the output data...')

data = loadmat('pav.mat')
pressure = data['pressure']
gradpr_r = data['gradpr_r']
gradpr_z = data['gradpr_z']

###esse script não dar erro na divisão por zero
x,y=pressure.shape
for xi in range(0,x):
    for yi in range(0,y):
        if abs(pressure[xi,yi])==0:
            pressure[xi,yi]=0.0000001+0.000001j
            
x,y=gradpr_r.shape
for xi in range(0,x):
    for yi in range(0,y):
        if abs(gradpr_r[xi,yi])==0:
            gradpr_r[xi,yi]=0.0000001+0.000001j
            
x,y=gradpr_z.shape
for xi in range(0,x):
    for yi in range(0,y):
        if abs(gradpr_z[xi,yi])==0:
            gradpr_z[xi,yi]=0.0000001+0.000001j            
            
tl = 20*log10(abs(pressure))
gr = 20*log10(abs(gradpr_r))
gz = 20*log10(abs(gradpr_z))

#Figura 1 = Pressure-------------------------------------------------
figure(1)
hold(True)
imshow(np.flipud(tl), extent=[0,Rmaxbox,0,-Dmax], aspect='auto')
plt.clim(-90, 0)
plt.set_cmap(cmap=jet())#altera a cor da plotagem
plt.colorbar()
plot(bathymetry[0,],-bathymetry[1,],color='r' , linewidth=2, )
xlim(0,Rmaxbox)#mKmmax
ylim(0, -Dmax)#Profmax
xlabel('Range (m)')
ylabel('Depth (m)')
title("TRACEO - Pekeris waveguide, p")
plt.gca().invert_yaxis() #o gráfico estava de 0 a 5000, com essa função ele está de 5000 a 0


#Figura 2 = gradpr_r-----------------------------------------------
figure(2)
hold(True)
imshow(np.flipud(gr), extent=[0,Rmaxbox,0,-Dmax], aspect='auto')
plt.clim(-90, 0)
plt.set_cmap(cmap=jet())#altera a cor da plotagem
plt.colorbar()
plot(bathymetry[0,],-bathymetry[1,],color='r' , linewidth=2, )
xlim(0,Rmaxbox)#mKmmax
ylim(0, -Dmax)#Profmax
xlabel('Range (m)')
ylabel('Depth (m)')
title("TRACEO - Pekeris waveguide, u")
plt.gca().invert_yaxis() #o gráfico estava de 0 a 5000, com essa função ele está de 5000 a 0

#Figura 3 = gradpr_z--------------------------------------------------
figure(3)
hold(True)
imshow(np.flipud(gz), extent=[0,Rmaxbox,0,-Dmax], aspect='auto')
plt.clim(-90, 0)
plt.set_cmap(cmap=jet())#altera a cor da plotagem
plt.colorbar()
plot(bathymetry[0,],-bathymetry[1,],color='r' , linewidth=2, )
xlim(0,Rmaxbox)#mKmmax
ylim(0, -Dmax)#Profmax
xlabel('Range (m)')
ylabel('Depth (m)')
title("TRACEO - Pekeris waveguide, w")
plt.gca().invert_yaxis() #o gráfico estava de 0 a 5000, com essa função ele está de 5000 a 0


plt.show()

print "feito"
