#-*- coding: utf-8 -*-

import os
import sys
from math import *
from numpy import *
from scipy.io import *
from pylab import *
from scipy.signal.ltisys import lsim
sys.path.insert(0, "../../P-files")
from wtraceoinfil import *
from curses.ascii import TAB

os.system("rm -rf pvl.mat")

case_title = "Pekeris waveguide & pressure and velocity"

'''%==================================================================
% 
% Define source data:
%
%==================================================================
'''

freq   = 717
Rmaxkm = 0.2
Rmax = Rmaxkm*1000
Dmax   =  50

ray_step = Rmax/1000 

zs = Dmax/2
rs = 0
thetamax = 15
nthetas = 50
la = linspace(-thetamax,thetamax,nthetas)

source_data = {}
source_data['ds'] = ray_step
source_data['position'] = [rs,zs]
source_data['rbox'] = [rs-1,Rmax+1]
source_data['f'] = freq
source_data['thetas'] = la

'''%==================================================================
%
% Define altimetry data:
% 
%=================================================================='''

alti = [rs-2, Rmax+2]
altimetry  = array([alti,[0,0]])

surface_data = {}
surface_data['type']  =   "V"#; % 
surface_data['ptype'] =   "H"#; % Homogeneous
surface_data['units'] =   "W"#; % (Attenuation Units) Wavelenght
surface_data['itype'] =  "FL"#;
surface_data['x']     = altimetry #; % Surface coordinates
surface_data['properties'] = [0.0,0.0,0.0,0.0,0.0] #aqui são 5 parametros

#==================================================================
#
# Define sound speed data:
#
#==================================================================

c0 = 1500

ssp_data = {}
ssp_data['cdist'] = "c(z,z)" #; # Sound speed field
ssp_data['cclass'] = "ISOV"
ssp_data['z']    = array([0, Dmax])
ssp_data['r']    = []
ssp_data['c']    = array([c0, c0]) 

'''%==================================================================
%  
%  Define object data:
%  
%=================================================================='''
npo = 50
cobjp = 2000
cobjs = 200
rhoo = 5
alphao = 0
R0 = 2
factor = 1.5
ro = [125,75]
zo = [35,25]

robj1  =  factor*R0*cos( linspace(pi,0,npo) ) + ro[0]
robj2 =  factor*R0*cos( linspace(pi,0,npo) ) + ro[1]
zup   =         R0*sin( linspace(pi,0,npo) )
zdn   =        -R0*sin( linspace(pi,0,npo) ) 
zdn1  = zdn + zo[0]
zdn2  = zdn + zo[1]
zup1  = zup + zo[0]
zup2  = zup + zo[1]

xboj1 = array([robj1,zdn1,zup1])
xboj2 = array([robj2,zdn2,zup2])

object_data = {}
object_data['nobjects'] = 2 #; % 2 objects
object_data['itype']     = "2P" #; % Objects interpolation type
object_data['npobjects'] = [npo, npo] #; % Number of points in each object1 -parei aqui
object_data['type']      = ["R", "R"] #; %objeto2
object_data['units']     = ["W", "W"]#; % (Attenuation Units) Wavelenght 
object_data['properties'] = [cobjp, cobjs, rhoo, alphao, alphao], [cobjp, cobjs, rhoo, alphao, alphao]
object_data['x'] = [xboj1,xboj2]

'''%==================================================================
% 
% Define bathymetry data:
%
%=================================================================='''

#% Gaussian sea mountain: 

bati = [rs-2, Rmax+2]
bathymetry = array([bati, [Dmax, Dmax]])

bottom_data = {}
bottom_data['type']   = "E"
bottom_data['ptype']  = "H" #; % Homogeneous bottom
bottom_data['units']  =  "W" #; % (Attenuation Units) Wavelenght
bottom_data['itype']  = "FL" #; % Bottom interpolation type 
bottom_data['x']      = bathymetry #;     % Bottom coordinates 
bottom_data['properties'] = [1700.0,0.0,1.7,0.7,0.0] #; % Bottom properties (speed, speed, density, absorption coefficient)

'''%==================================================================
%
% Define output data:
%
%=================================================================='''

nra = 201
rarray = linspace(0,Rmax,nra)
nza = 201
zarray = linspace(0,Dmax,nza)


output_data={}
output_data['ctype']       = "PVL" #''';
output_data['array_shape'] = "RRY" #''';
output_data['r']           = rarray
output_data['z']           = zarray
output_data['miss']        = 0.5

'''%==================================================================
%  
%  Call the function:
%  
%=================================================================='''

print('Writing TRACEO waveguide input file...')

wtraceoinfil('pekeris.in',case_title,source_data,surface_data,ssp_data,object_data,bottom_data,output_data)

print('Calling TRACEO...')

os.system('runtraceo pekeris')

print('Reading the output data...')

data = loadmat('pvl.mat')

gradpr_r = data['gradpr_r']
gradpr_z = data['gradpr_z']

x,y=gradpr_r.shape
for xi in range(0,x):
    for yi in range(0,y):
        if abs(gradpr_r[xi,yi])==0:
            gradpr_r[xi,yi]=0.0000001+0.000001j
            
x,y=gradpr_z.shape
for xi in range(0,x):
    for yi in range(0,y):
        if abs(gradpr_z[xi,yi])==0:
            gradpr_z[xi,yi]=0.0000001+0.000001j            
            
gr = 20*log10(abs(gradpr_r))
gz = 20*log10(abs(gradpr_z))

#Figura 1 = gradpr_r
figure(1)
hold(True)
imshow(np.flipud(gr), extent=[0,Rmax,0,-Dmax], aspect='auto')
plt.clim(-90, 0)
plt.set_cmap(cmap=jet())#altera a cor da plotagem
plt.colorbar()
#---------objeto-------------------------
fill_between(robj1,-zup1,-zdn1)
fill_between(robj2,-zup2,-zdn2)

xlim(0,Rmax)#mKmmax
ylim(0, -Dmax)#Profmax
xlabel('Range (m)')
ylabel('Depth (m)')
title("TRACEO - Pekeris waveguide, u")
plt.gca().invert_yaxis() #o gráfico estava de 0 a 5000, com essa função ele está de 5000 a 0

#Figura 2 = gradpr_z
figure(2)
hold(True)
imshow(np.flipud(gz), extent=[0,Rmax,0,-Dmax], aspect='auto')
plt.clim(-90, 0)
plt.set_cmap(cmap=jet())#altera a cor da plotagem
plt.colorbar()
#---------objeto-------------------------
fill_between(robj1,-zup1,-zdn1)
fill_between(robj2,-zup2,-zdn2)

xlim(0,Rmax)#mKmmax
ylim(0, -Dmax)#Profmax
xlabel('Range (m)')
ylabel('Depth (m)')
title("TRACEO - Pekeris waveguide, w")
plt.gca().invert_yaxis() #o gráfico estava de 0 a 5000, com essa função ele está de 5000 a 0

plt.show()

print "feito"

