#-*- coding: utf-8 -*-

import os
import sys
from math import *
from numpy import *
from scipy.io import *
from pylab import *
import matplotlib.pyplot as plt
from scipy.signal.ltisys import lsim
sys.path.insert(0, "../../P-files")
from wtraceoinfil import *
from curses.ascii import TAB

os.system("rm -rf rco.mat")

case_title = "Pekeris waveguide & ray coordinates"

'''%==================================================================
% 
% Define source data:
%
%==================================================================
'''
freq   =    707
Rmaxkm =   0.2
Rmax = Rmaxkm*1000
Dmax   =  50

ray_step = Rmax/1000 

zs = Dmax/2
rs = 0
nthetas = 50
thetamax = 15

thetas = linspace(-thetamax,thetamax,nthetas)

source_data = {}
source_data['ds'] = ray_step
source_data['position'] = [rs,zs]
source_data['rbox'] = [rs-1,Rmax+1]
source_data['f'] = freq
source_data['thetas'] = thetas

'''%==================================================================
%
% Define altimetry data:
% 
%=================================================================='''

alti = [rs-2, Rmax+2]
altimetry  = array([alti,[0,0]])

surface_data = {}
surface_data['type']  =   "V"#; % 
surface_data['ptype'] =   "H"#; % Homogeneous
surface_data['units'] =   "W"#; % (Attenuation Units) Wavelenght
surface_data['itype'] =  "FL"#;
surface_data['x']     = altimetry #; % Surface coordinates
surface_data['properties'] = [0.0,0.0,0.0,0.0,0.0] #aqui são 5 parametros

#==================================================================
#
# Define sound speed data:
#
#==================================================================

c0 = 1500

ssp_data = {}
ssp_data['cdist'] = "c(z,z)" #; # Sound speed field
ssp_data['cclass'] = "ISOV"
ssp_data['z']    = array([0, Dmax])
ssp_data['r']    = []
ssp_data['c']    = array([c0, c0]) 

'''%==================================================================
%  
%  Define object data:
%  
%=================================================================='''

npo = 50 #
cobjp = 2000 #velocida compressional do objeto
cobjs = 200 #velocidade cisalhamento
rhoo = 5#densidade do objeto
alphao = 0 #atnuação compressional do objeto
R0 = 5 #raio da esfera
factor = 1
ro = Rmax/2 #ponto central da esfera em distancia
zo = Dmax/2 #ponto central da esfera em profundidade

#definição de um objeto em forma de esfera
robj  =  factor*R0*cos( linspace(pi,0,npo) ) + ro #coordenadas horizontais do objeto
zup   =         R0*sin( linspace(pi,0,npo) ) + Dmax/2 #face superior do objeto
zdn   =        -R0*sin( linspace(pi,0,npo) ) + Dmax/2 #face inferior do objeto

xboj = array([robj,zdn,zup])

object_data = {}
object_data['nobjects'] = 1 #; % No objects
object_data['itype']     = "2P" #; % Objects interpolation type
object_data['npobjects'] = [npo] #; % Number of points in each object
object_data['type']      = ["R"] #; %
object_data['units']     = ["W"]#; % (Attenuation Units) Wavelenght 
object_data['properties'] = [cobjp, cobjs, rhoo, alphao, alphao],[]
object_data['x'] = (xboj, [])


'''%==================================================================
% 
% Define bathymetry data:
%
%=================================================================='''

#% Gaussian sea mountain: 

bati = [rs-2, Rmax+2]
bathymetry = array([bati, [Dmax, Dmax]])

bottom_data = {}
bottom_data['type']   = "E"
bottom_data['ptype']  = "H" #; % Homogeneous bottom
bottom_data['units']  =  "W" #; % (Attenuation Units) Wavelenght
bottom_data['itype']  = "FL" #; % Bottom interpolation type 
bottom_data['x']      = bathymetry #;     % Bottom coordinates 
bottom_data['properties'] = [1700.0,0.0,1.7,0.7,0.0] #; % Bottom properties (speed, speed, density, absorption coefficient)

'''%==================================================================
%
% Define output data:
%
%=================================================================='''

output_data={}
output_data['ctype']       = "RCO" #''';
output_data['array_shape'] = "VRY" #''';
output_data['r']           = array([Rmax])
output_data['z']           = array([Dmax])
output_data['miss']        = 0.5

'''%==================================================================
%  
%  Call the function:
%  
%=================================================================='''

print('Writing TRACEO waveguide input file...')

wtraceoinfil('pekeris.in',case_title,source_data,surface_data,ssp_data,object_data,bottom_data,output_data)

print('Calling TRACEO...')

os.system('runtraceo pekeris')

print('Reading the output data...')

data = loadmat('rco.mat')

thetas = data["ray_elev"] 

nthetas = thetas.size
figure(1)
hold(True)
for i in range(1, nthetas+1):
    if i<10:
        rayname = "ray0000" + str(i)
    elif i<100:
        rayname = "ray000" + str(i)
    elif i<1000:
        rayname = "ray00" + str(i)
    elif i<10000:
        rayname = "ray0" + str(i)
    else:
        rayname = "ray" + str(i)
        
    rayi = data[rayname]
    r = rayi[0,]
    z =-rayi[1,]
    plot(r,z)
    
xlabel('Range(m)')
ylabel('Depht (m)')
plot(bathymetry[0,],-bathymetry[1,],color='r' , linewidth=2, )
plot(altimetry[0,],-altimetry[1,],color='b',linewidth=2)
fill_between(robj,-zup,-zdn)
grid(True)

title('TRACEO - Pekeris waveguide, ray coordinates')

'''
plt.fill(xboj[1,],xboj[2,],color='b')
plt.fill(xboj[1,],xboj[3,],color='b')

fill(xobj(1,:),xobj(2,:),'k')
fill(xobj(1,:),xobj(3,:),'k')

'''

xlim(0, Rmax)
ylim(-Dmax, 0)
show()
    
print "feito"
